package metier;

import java.util.Objects;
import javax.swing.Icon;
import javax.swing.JOptionPane;
import static javax.swing.JOptionPane.DEFAULT_OPTION;
import static javax.swing.JOptionPane.QUESTION_MESSAGE;

/**
 *
 * @author Dominique_2
 */
public class Sorcier  extends Personnage {
    
    private String baguette;
    private Enigme[] enigmes;

    public Sorcier(String nom, String img, int energie, int dureeVie, String baguette, Enigme[] enigmes) {
        super(nom, img, energie, dureeVie);
        this.baguette = baguette;
        this.enigmes = enigmes;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = super.hashCode() + (73 * hash + Objects.hashCode(this.baguette));
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Sorcier other = (Sorcier) obj;
        if (!Objects.equals(this.baguette, other.baguette)) {
            return false;
        }
        if (!super.equals(obj)) {
            return false;            
        }
        return true;
    }

    @Override
    public String toString() {
        return super.toString() + "\tBaguette=" + baguette + "\nNb Enigmes";
    }
        
    /**
     * Get the value of baguette
     *
     * @return the value of baguette
     */
    public String getBaguette() {
        return baguette;
    }
    
    public Enigme[] getEnigmes() {
        return this.enigmes;
    }
    
    /**
     * Rsume les informations sur le personnage
     * @return Informations du personnage
     */
    @Override
    public String resumerPersonnage() {
        String str = "";
        str  += "Nom    "+this.getNom()+"\n";
        str  += "nergie    "+this.getEnergie()+"\n";
        str  += "Dure de vie    "+this.getDureeVie()+"\n";
        str  += "Sorcier    arme : "+this.getBaguette()+"\n";
        
        return str;
    }
    
    public void ajouterEnigme(Enigme e) {
        int tailleEnigmes = this.enigmes.length+1;
        Enigme[] enigmes = new Enigme[tailleEnigmes];
        for (int i = 0; i < this.enigmes.length; i++) {
            enigmes[i] = this.enigmes[i];
        }
        enigmes[this.enigmes.length] = e;
        
        this.enigmes = enigmes;
    };

    /**
     * Set the value of baguette
     *
     * @param baguette new value of baguette
     */
    public void setBaguette(String baguette) {
        this.baguette = baguette;
    }
    
    /**
     * Initie la rencontre avec un autre personnage
     * @param unPerso un Personnage
     * @return Message de rencontre
     */
    public String rencontrer(Personnage unPerso) {
        // Message de défi à l'adversaire
        String titre = this.getNom() + " rencontre " + unPerso.getNom() + " : Enigme";
        String message = "Es-tu prêt à me combattre "+ unPerso.getNom() +" ?\n\nJeu d'énigme";
        
        // Icone du jeu d'énigme à afficher
        Icon iEnigme = new javax.swing.ImageIcon(getClass().getResource("/img/adj_1.jpg"));
        
        // Envoi du message et de l'icone dans une boite de dialogue
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, iEnigme);
        
        
        // Numéro d'énigme aléatoire
        int idQuestion = Jeu.genererNbAleatoire(0, this.enigmes.length-1);
        
        // Message de choix du PFC
        String question = this.enigmes[idQuestion].getQuestion();
        String reponseVrai = this.enigmes[idQuestion].getReponse();
        
        message = question;
        // Choix du joueur avec des boutons
        String reponse = (String) JOptionPane.showInputDialog(null, message, titre, QUESTION_MESSAGE, null, null, null);
        
        // Comparaison des choix pour définir un vainqueur
        message = "Ma question: "+ question +"\nTa réponse: "+ reponse +"\nLa réponse: "+ reponseVrai +"\n\n";
        
        // Prendra en valeur l'image du vainqueur si vainqueur, il y a
        Icon ImgVainqueur;
        
        if (!reponse.equals(reponseVrai)) { // Si this Voleur gagne
            // Message de victoire
            message += this.getNom() +" l'emporte !\n\n";
            ImgVainqueur = new javax.swing.ImageIcon(getClass().getResource("/img/"+ this.getNom() +".jpg"));
            
            // Ajout d'un point d'énergie au Voleur
            unPerso.setDureeVie(unPerso.getDureeVie()-2);
        } else { // Si l'autre combattant gagne
            // Message de victoire
            message += unPerso.getNom() +" l'emporte !\n\n";
            ImgVainqueur = new javax.swing.ImageIcon(getClass().getResource("/img/"+ unPerso.getNom() +".jpg"));
            
            // Retrait d'un point d'énergie au Voleur
            unPerso.setEnergie(this.getEnergie()+2);
        }
        
        // Message d'information sur les vies de chaque partie
        message += this.getNom() +": "+ this.getDureeVie()+" - "+ unPerso.getNom() +": "+ unPerso.getDureeVie();
        
        // Envoi du message et de l'icone dans une boîte du dialogue
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, ImgVainqueur);
        return message;
    }
    
    /**
      * Saluer un personnage
      * @param unPerso Un personnage
      * @return Message de salutation
      */
    @Override
    public String saluer(Personnage unPerso) {
        String titre = this.getNom() + " salue " + unPerso.getNom();
        String message = "Bonjour " + unPerso.getNom() + ", je t'ai jeté un sort, tu es désormais sous ma dépendance !";
        //JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
        Icon imgPerso = new javax.swing.ImageIcon(getClass().getResource("/img/" + this.getImg()));
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, imgPerso);       
        return message;
    }
}
